@@ -1,4 +1,5 @@
 # Copyright (C) 2003 Jean-Pierre Gattuso and Aurelien Proye
+# with valuable suggestions from Jean-Marie Epitalon <epitalon@lsce.saclay.cea.fr>
 #
 # This file is part of seacarb.
 #
@@ -26,7 +27,7 @@ resultat="carb.out";
 
 # flag = 1      pH-CO2 given
 # flag = 2      CO2-HCO3 given
-# flag = 3      CO2-CO3 given  
+# flag = 3      CO2-CO3 given
 # flag = 4      CO2-ALK given
 # flag = 5      CO2-DIC given
 # flag = 6      pH and HCO3 given
@@ -47,85 +48,85 @@ if (ini=='s')
 	PH=var1;
 	CO2=var2/1000000;
 	}
-	
+
 	if (flag==2)
 	{
 	CO2=var1/1000000;
 	HCO3=var2/1000000;
 	}
-	
+
 	if (flag==3)
 	{
 	CO2=var1/1000000;
 	CO3=var2/1000000;
 	}
-	
+
 	if (flag==4)
 	{
 	CO2=var1/1000000;
 	ALK=var2/1000000;
 	}
-	
+
 	if (flag==5)
 	{
 	CO2=var1/1000000;
 	DIC=var2/1000000;
 	}
-	
+
 	if (flag==6)
 	{
 	PH=var1;
 	HCO3=var2/1000000;
 	}
-	
+
 	if (flag==7)
 	{
 	PH=var1;
 	CO3=var2/1000000;
 	}
-	
+
 	if (flag==8)
 	{
 	PH=var1;
 	ALK=var2/1000000;
 	}
-	
+
 	if (flag==9)
 	{
 	PH=var1;
 	DIC=var2/1000000;
 	}
-	
+
 	if (flag==10)
 	{
 	HCO3=var1/1000000;
 	CO3=var2/1000000;
 	}
-	
+
 	if (flag==11)
 	{
 	HCO3=var1/1000000;
 	ALK=var2/1000000;
 	}
-	
+
 	if (flag==12)
 	{
 	HCO3=var1/1000000;
 	DIC=var2/1000000;
 	}
-	
+
 	if (flag==13)
 	{
 	CO3=var1/1000000;
 	ALK=var2/1000000;
 	}
-	
+
 	if (flag==14)
 	{
 	CO3=var1/1000000;
 	DIC=var2/1000000;
 	}
-	
+
 	if (flag==15)
 	{
 	ALK=var1/1000000;
@@ -144,37 +145,32 @@ n=1;
 
 #-------Constantes----------------
 
-#---- issues de equic----
 tk = 273.15;           # [K] (for conversion [deg C] <-> [K])
-TC = T + tk;           # TC [C]; T[K]
-Cl = S / 1.80655;      # Cl = chlorinity; S = salinity (per mille)
-cl3 = Cl^(1/3);   
-ION = 0.00147 + 0.03592 * Cl + 0.000068 * Cl * Cl;   # ionic strength
-iom0 = 19.924*S/(1000-1.005*S);
-ST = 0.14/96.062/1.80655*S;   # (mol/kg soln) total sulfate
-
-
-bor = (416.*(S/35.))* 1e-6;   # (mol/kg), DOE94   
 
 
 if (ini=='f')
 {
-fich<-file.choose();
-Data <- read.delim(fich, sep="\t", header=TRUE);
-l=nchar(fich);
-st=l-3;
-r=substr(fich,1,st);
-resu=paste(r,"out",sep="");
-TPH=Data$PH;
-TCO2=Data$CO2;
-THCO3=Data$HCO3;
-TCO3=Data$CO3;
-TDIC=Data$DIC;
-TALK=Data$ALK;
-TS=Data$S;
-TT=Data$T;
-TP=Data$P;
-n=nrow(Data);
+    fich<-file.choose();
+    # fich<-"seacarb.inp"
+    Data <- read.delim(fich, sep="\t", header=TRUE);
+    l=nchar(fich);
+    st=l-3;
+    r=substr(fich,1,st);
+    resu=paste(r,"out",sep="");
+    # JME: added read flag value from file
+    Tflag=Data$flag;
+    TPH=Data$PH;
+    TCO2=Data$CO2;
+    THCO3=Data$HCO3;
+    TCO3=Data$CO3;
+    TDIC=Data$DIC;
+    TALK=Data$ALK;
+    TS=Data$S;
+    TT=Data$T;
+    TP=Data$P;
+    n=nrow(Data);
+
+    cat ("n:\t", n)
 }
 
 
@@ -185,6 +181,8 @@ for (i in 1:n)
 	if (ini=='f')
 
 	{
+	# JME: added read flag value from file
+	flag=Tflag[i];
 	PH=TPH[i];
 	CO2=TCO2[i];
 	HCO3=THCO3[i];
@@ -195,13 +193,26 @@ for (i in 1:n)
 	T=TT[i];
 	P=TP[i];
 	}
-	
+
+	# JME: moved following code block here, after reading imput file
+
+	TC = T + tk;           # TC [C]; T[K]
+
+    #---- issues de equic----
+    Cl = S / 1.80655;      # Cl = chlorinity; S = salinity (per mille)
+    cl3 = Cl^(1/3);
+    ION = 0.00147 + 0.03592 * Cl + 0.000068 * Cl * Cl;   # ionic strength
+    iom0 = 19.924*S/(1000-1.005*S);
+    ST = 0.14/96.062/1.80655*S;   # (mol/kg soln) total sulfate
+
+
+    bor = (416.*(S/35.))* 1e-6;   # (mol/kg), DOE94
 
 
 	#---------------------------------------------------------------------
 	#------------- calcul des K ----------------------------------
 	#---------------------------------------------------------------------
-		
+
 	#--------------------------------------------------------------
 	#------------------ Ks ----------------------------------------
 	#       Dickson and Goyet (1994), Chapter 5, p.13
@@ -213,25 +224,25 @@ for (i in 1:n)
 	#
 	#       the term log(1-0.001005*S) converts from
 	#       mol/kg H2O to mol/kg soln
-	
-	
+
+
 	tmp1 = -4276.1 / TC + 141.328 -23.093*log(TC);
 	tmp2 = +(-13856 / TC + 324.57 - 47.986 * log(TC))*sqrt(iom0);
 	tmp3 = +(35474 / TC - 771.54 + 114.723 * log(TC))*iom0;
 	tmp4 = -2698 / TC *sqrt(iom0)*iom0 + 1776 / TC *iom0 *iom0;
-	                                       
-	
+
+
 	lnKs = tmp1 + tmp2 + tmp3 + tmp4 + log(1-0.001005*S);
-	
+
 	Ks = exp(lnKs);
 	#------- total2free -----------------------------------------------
 	#
 	#       convert from pH_total ('total`) to pH ('free`):
 	#       pH_total = pH_free - log(1+ST/KS(s,tk))
-	
+
 	total2free = 1+ST/Ks;
-	
-	
+
+
 	#---------------------------------------------------------------------
 	# --------------------- Kf  ------------------------------------------
 	#  Kf = [H+][F-]/[HF]  
@@ -239,12 +250,12 @@ for (i in 1:n)
 	#   (Dickson and Riley, 1979 in Dickson and Goyet, 
 	#   1994, Chapter 5, p. 14)
 	#   pH-scale: 'total'   
-	
-	
+
+
 	tmp1 = 1590.2/TC - 12.641 + 1.525*sqrt(ION);
 	tmp2 = log(1-0.001005*S) + log(1+ST/Ks);
-	
-	
+
+
 	lnKf = tmp1 + tmp2;
 	if (phflag == 0)
 	{
@@ -262,26 +273,26 @@ for (i in 1:n)
 	#
 	#       convert from pH_sws ('seawater scale`) to pH ('free`):
 	#       pH_sws = pH_free - log(1+S_T/K_S(S,T)+F_T/K_F(S,T))
-	
-	
+
+
 	FT = 7e-5*(S/35);
 	sws2free  = (1+ST/Ks+FT/Kf);
 	corr = sws2free/total2free;
-	
-	
+
+
 	#-------------------------------------------------------------------
 	# --------------------- Kwater -------------------------------------
 	#
 	#       Millero (1995)(in Dickson and Goyet (1994, Chapter 5, p.18))
 	#       $K_w$ in mol/kg-soln.
 	#       pH-scale: pH$_{total}$ ('total` scale).
-	                                                     
-	
+
+
 	tmp1 = -13847.26/TC + 148.96502 - 23.6521 * log(TC);
 	tmp2 = + (118.67/TC - 5.977 + 1.0495*log(TC))*sqrt(S) - 0.01615*S;
-	
+
 	lnKw =  tmp1 + tmp2;
-	
+
 	if (phflag == 0)
 	{
 	        Kw  = exp(lnKw);
@@ -291,8 +302,8 @@ for (i in 1:n)
 	        lnKw = lnKw-log(total2free);
 	        Kw  = exp(lnKw);
 	}
-	
-	
+
+
 	#---------------------------------------------------------------------
 	#---------------------- Kh (K Henry) ---------------------------------
 	#
@@ -304,31 +315,31 @@ for (i in 1:n)
 	#
 	tmp = 9345.17 / TC - 60.2409 + 23.3585 * log(TC/100);
 	nKhwe74 = tmp + S*(0.023517-0.00023656*TC+0.0047036e-4*TC*TC);
-	
+
 
 	Kh= exp(nKhwe74);
+
+
 	
-	
-		
 	#---------------------------------------------------------------------------------
 	#---------------------- Choix des constantes K1 et K2 ----------------------------
 	#---------------------------------------------------------------------------------
+
 	
-		
 	# --------------------- K1 ---------------------------------------
 	#   first acidity constant:
 	#   [H^+] [HCO_3^-] / [CO2] = K_1
 	#
 	#   (Roy et al., 1993 in Dickson and Goyet, 1994, Chapter 5, p. 14)
 	#   pH-scale: 'total'. mol/kg-soln
-	
+
 	tmp1 = 2.83655 - 2307.1266 / TC - 1.5529413 * log(TC);
 	tmp2 =         - (0.20760841 + 4.0484 / TC) * sqrt(S);
 	tmp3 =         + 0.08468345 * S - 0.00654208 * S * sqrt(S);   
 	tmp4 =         + log(1 - 0.001005 * S);
-	
+
 	lnK1roy = tmp1 + tmp2 + tmp3 + tmp4;
-	
+
 	if (phflag == 0)
 	{
 	        K1roy  = exp(lnK1roy);
@@ -338,8 +349,8 @@ for (i in 1:n)
 	        lnK1roy = lnK1roy-log(total2free);
 	        K1roy   = exp(lnK1roy);
 	}
-	
-	
+
+
 	# --------------------- K2 ----------------------------------------
 	#
 	#   second acidity constant:
@@ -347,24 +358,24 @@ for (i in 1:n)
 	#
 	#   (Roy et al., 1993 in Dickson and Goyet, 1994, Chapter 5, p. 15)
 	#   pH-scale: 'total'. mol/kg-soln
-	
+
 	tmp1 = -9.226508 - 3351.6106 / TC - 0.2005743 * log(TC);
 	tmp2 = (-0.106901773 - 23.9722 / TC) * sqrt(S);
 	tmp3 = 0.1130822 * S - 0.00846934 * S^1.5 + log(1 - 0.001005 * S);
-	
+
 	lnK2roy = tmp1 + tmp2 + tmp3;
-	
+
 	if (phflag == 0)
 	{
 	        K2roy  = exp(lnK2roy);
 	}
-	
+
 	if (phflag == 1)
 	{
 	        lnK2roy = lnK2roy-log(total2free);
 	        K2roy   = exp(lnK2roy);
 	}
-	
+
 	# --------------------- K1 ---------------------------------------
 	#   first acidity constant:
 	#   [H^+] [HCO_3^-] / [H_2CO_3] = K_1
@@ -374,7 +385,7 @@ for (i in 1:n)
 	#   pH-scale: 'total'. mol/kg-soln
 
 	pK1mehr = 3633.86/TC - 61.2172 + 9.6777*log(TC) - 0.011555*S + 0.0001152*S*S;
-	
+
 	if (phflag == 0)
 	{
 	        K1mehr  = 10^(-pK1mehr);
@@ -384,8 +395,8 @@ for (i in 1:n)
 		lnK1mehr = log(10^(-pK1mehr))-log(total2free);
 	        K1mehr   = exp(lnK1mehr);
 	}
-	
-	
+
+
 	# --------------------- K2 ----------------------------------------
 	#
 	#   second acidity constant:
@@ -394,9 +405,9 @@ for (i in 1:n)
 	#   Mehrbach et al. (1973) refit by Lueker et al. (2000).
 	#
 	#   pH-scale: 'total'. mol/kg-soln
-	
+
 	pK2mehr = 471.78/TC + 25.9290 - 3.16967*log(TC) - 0.01781*S + 0.0001122*S*S;
-	
+
 	if (phflag == 0)
 	{
 	        K2mehr  = 10^(-pK2mehr);
@@ -406,27 +417,27 @@ for (i in 1:n)
 		lnK2mehr = log(10^(-pK2mehr))-log(total2free);
 	        K2mehr   = exp(lnK2mehr);
 	}
-	
-	
+
+
 	#----------- Roy or Mehrbach. default: Roy 
 
 	K1 = K1roy;
 	K2 = K2roy;
-	
+
 	if (exists('k1k2flag'))
 	{
 		if (k1k2flag == 0)
-		{	
+		{
 		K1 = K1roy;
 		K2 = K2roy;
 		}
-	
+
 		if (k1k2flag == 1)
 		{
 		K1 = K1mehr;
 		K2 = K2mehr;
 		}
-	
+
 	}
 
 
@@ -437,14 +448,14 @@ for (i in 1:n)
 	#
 	#   (Dickson, 1990 in Dickson and Goyet, 1994, Chapter 5, p. 14)
 	#   pH-scale: 'total'. mol/kg-soln
-	
-	
+
+
 	tmp1 =  (-8966.90-2890.53*sqrt(S)-77.942*S+1.728*S^(3/2)-0.0996*S*S);
 	tmp2 =   +148.0248+137.1942*sqrt(S)+1.62142*S;
 	tmp3 = +(-24.4344-25.085*sqrt(S)-0.2474*S)*log(TC);
-	
+
 	lnKb = tmp1 / TC + tmp2 + tmp3 + 0.053105*sqrt(S)*TC;
-	
+
 	if (phflag == 0)
 	{
 	        Kb  = exp(lnKb);
@@ -454,7 +465,7 @@ for (i in 1:n)
 	        lnKb = lnKb-log(total2free);
 	        Kb  = exp(lnKb);
 	}
-	
+
 
 
 
@@ -463,27 +474,27 @@ for (i in 1:n)
 	#   (DOE, 1994)  (Dickson and Goyet): pH_T, mol/(kg-soln)
 	#   Ch.5 p. 16
 	#
-	
+
 	lnK1P = -4576.752 / TC + 115.525 - 18.453*log(TC) + (-106.736 / TC + 0.69171) * sqrt(S) + (-0.65643 / TC - 0.01844) * S;
 	lnK2P = -8814.715 / TC + 172.0883 - 27.927 * log(TC) + (-160.34 / TC + 1.3566) * sqrt(S) + (0.37335 / TC - 0.05778) * S;
 	lnK3P = -3070.75 / TC - 18.141 + (17.27039 / TC + 2.81197) * sqrt(S) + (-44.99486 / TC - 0.09984) * S;
-	
+
 	K1P = exp(lnK1P);
 	K2P = exp(lnK2P);
 	K3P = exp(lnK3P);
-	
+
 	# --------------------- Silicic acid ---------------------------
 	#
 	#   (DOE, 1994)  (Dickson and Goyet): pH_T, mol/(kg-soln)
 	#   Ch.5 p. 17
 	#
-	
-	
+
+
 	lnKSi = -8904.2 / TC + 117.385 - 19.334*log(TC) + (3.5913-458.79 / TC) * sqrt(iom0) + (188.74 / TC - 1.5998) * iom0 + (0.07871 - 12.1652 / TC) *iom0^2 + log(1-0.001005*S);
-	
+
 	KSi = exp(lnKSi);
-	
-	
+
+
 
 	# --------------------- Kspc (calcite) ----------------------------
 	#
@@ -495,12 +506,12 @@ for (i in 1:n)
 	# (free + complexed) ion concentration.
 	#
 	#  Mucci 1983 mol/kg-soln
-	
+
 	tmp1 = -171.9065-0.077993*TC+2839.319/TC+71.595*log10(TC);
 	tmp2 = +(-0.77712+0.0028426*TC+178.34/TC)*sqrt(S);
 	tmp3 = -0.07711*S+0.0041249*S^1.5;
 	log10Kspc = tmp1 + tmp2 + tmp3;
-	
+
 	Kspc = 10^(log10Kspc);
 
 	# --------------------- Kspa (aragonite) ----------------------------
@@ -513,12 +524,12 @@ for (i in 1:n)
 	# (free + complexed) ion concentration.
 	#
 	#  Mucci 1983 mol/kg-soln
-	
+
 	tmp1 = -171.945-0.077993*TC+2903.293/TC+71.595*log10(TC);
 	tmp2 = +(-0.068393+0.0017276*TC+88.135/TC)*sqrt(S);
 	tmp3 = -0.10018*S+0.0059415*S^1.5;
 	log10Kspa = tmp1 + tmp2 + tmp3;
-	
+
 	Kspa = 10^(log10Kspa);
 
 
@@ -530,56 +541,56 @@ for (i in 1:n)
 
 
 	#------------ Density of pure water
-	
+
 	rhow = 999.842594 + 6.793952e-2*T -9.095290e-3*T^2 + 1.001685e-4*T^3 -1.120083e-6*T^4 + 6.536332e-9*T^5;
-	
+
 	#------------ Density of seawater at 1 atm, P=0
-	
+
 	A = 8.24493e-1 - 4.0899e-3*T + 7.6438e-5*T^2 - 8.2467e-7*T^3 + 5.3875e-9*T^4; 
-	B = -5.72466e-3 + 1.0227e-4*T - 1.6546e-6*T^2; 	
+	B = -5.72466e-3 + 1.0227e-4*T - 1.6546e-6*T^2; 
 	C = 4.8314e-4;   
-	
+
 	rho0 = rhow + A*S + B*S^(3/2) + C*S^2;
-	
-	
+
+
 	#-------------- Secant bulk modulus of pure water 
 	#
 	# The secant bulk modulus is the average change in pressure 
 	# divided by the total change in volume per unit of initial volume.
-	
-	
+
+
 	Ksbmw = 19652.21 + 148.4206*T - 2.327105*T^2 + 1.360477e-2*T^3 - 5.155288e-5*T^4;
-	
+
 	#-------------- Secant bulk modulus of seawater at 1 atm
-	
+
 	Ksbm0 = Ksbmw + S*( 54.6746 - 0.603459*T + 1.09987e-2*T^2 - 6.1670e-5*T^3) + S^(3/2)*( 7.944e-2 + 1.6483e-2*T - 5.3009e-4*T^2);
-	
-	
+
+
 	#-------------- Secant bulk modulus of seawater at S,T,P
-		
+	
 	Ksbm = Ksbm0 + P*( 3.239908 + 1.43713e-3*T + 1.16092e-4*T^2 - 5.77905e-7*T^3) + P*S*( 2.2838e-3 - 1.0981e-5*T - 1.6078e-6*T^2) + P*S^(3/2)*1.91075e-4 + P*P*(8.50935e-5 - 6.12293e-6*T + 5.2787e-8*T^2) + P^2*S*(-9.9348e-7 + 2.0816e-8*T + 9.1697e-10*T^2);
-	 	
-	
+	 
+
 	#------------- Density of seawater at S,T,P
-	
+
 	rho = rho0/(1-P/Ksbm);
-	
-	
+
+
 	#---------------------- Pressure effect on K's (Millero, 95) ----------#
-	
+
 	if (P > 0.0)
 	{
-	
+
 	RGAS = 8.314510;        # J mol-1 deg-1 (perfect Gas)  
 	R = 83.131;             # mol bar deg-1 
 	                        # conversion cm3 -> m3          *1.e-6
                   	        #            bar -> Pa = N m-2  *1.e+5
 	                        #                => *1.e-1 or *1/10
-	
-	
+
+
 	# index: K1 1, K2 2, Kb 3, Kw 4, Ks 5, Kf 6, Kspc 7, Kspa 8,
 	#        K1P 9, K2P 10, K3P 11
-	
+
 	#----- note: there is an error in Table 9 of Millero, 1995.
 	#----- The coefficients -b0 and b1
 	#----- have to be multiplied by 1.e-3!
@@ -587,27 +598,27 @@ for (i in 1:n)
 	#----- there are some more errors! 
 	#----- the signs (+,-) of coefficients in Millero 95 do not
 	#----- agree with Millero 79
-	
-	
-	
+
+
+
 	a0 = c(-25.5, -15.82, -29.48, -25.60, -18.03, -9.78, -48.76, -46, -14.51, -23.12, -26.57);
 	a1 = c(0.1271, -0.0219, 0.1622, 0.2324, 0.0466, -0.0090, 0.5304, 0.5304, 0.1211, 0.1758, 0.2020);
 	a2 = c(0.0, 0.0, 2.608*1e-3, -3.6246*1e-3, 0.316*1e-3, -0.942*1e-3, 0.0, 0.0, -0.321*1e-3, -2.647*1e-3, -3.042*1e-3);
 	b0 = c(-3.08*1e-3, 1.13*1e-3, -2.84*1e-3, -5.13*1e-3, -4.53*1e-3, -3.91*1e-3, -11.76*1e-3, -11.76*1e-3, -2.67*1e-3, -5.15*1e-3, -4.08*1e-3);
 	b1 = c(0.0877*1e-3, -0.1475*1e-3, 0.0, 0.0794*1e-3, 0.09*1e-3, 0.054*1e-3, 0.3692*1e-3, 0.3692*1e-3, 0.0427*1e-3, 0.09*1e-3, 0.0714*1e-3);
 	b2 = c(0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0);
-	
+
 	deltav = c(0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0);
 	deltak = c(0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0);
 	lnkpok0 = c(0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0);
-	
+
 	for (ipc in 1:length(a0))
 	{
 	  deltav[ipc]  =  a0[ipc] + a1[ipc] *T + a2[ipc] *T*T;
 	  deltak[ipc]   = (b0[ipc]  + b1[ipc] *T + b2[ipc] *T*T);  
 	  lnkpok0[ipc]  = -(deltav[ipc] /(R*TC))*P + (0.5*deltak[ipc] /(R*TC))*P*P;
 	}
-	
+
 	K1 = K1*exp(lnkpok0[1]);
 	K2 = K2*exp(lnkpok0[2]);
 	Kb = Kb*exp(lnkpok0[3]);
@@ -619,7 +630,7 @@ for (i in 1:n)
 	K1P = K1P*exp(lnkpok0[9]);
 	K2P = K2P*exp(lnkpok0[10]);
 	K3P = K3P*exp(lnkpok0[11]);
-	
+
 	}
 
 
@@ -632,11 +643,11 @@ for (i in 1:n)
 
 
 	# ----------------- case 1.) PH and CO2 given
-	
+
 	PHCO2 <- function(PH, CO2, K1, K2, bor, Kb, Kw, Kh, Kspa, Kspc, S, TC, P)
-	
+
 	{
-	
+
 	#disp('flag = 1, pH and CO2 given');
 	h=10^(-PH);
 	s=CO2;
@@ -645,25 +656,28 @@ for (i in 1:n)
 	CO3 = DIC/(1+h/K2+h*h/K1/K2);
 	ALK = s*(K1/h+2.*K1*K2/h/h)+Kb*bor/(Kb+h)+Kw/h-h;                        
 	pCO2 = s*1.e6/Kh;
-		
+
 	Oa = ((0.01028*(S/35))*CO3)/Kspa;
 	Oc = ((0.01028*(S/35))*CO3)/Kspc;
 
-	
-	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
-	fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
-	
-	
+
+	# JME: corrected fugacity calculation
+	# B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
+	# fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
+	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))*1e-6;
+	fCO2= pCO2*exp(((P+1)*100000)*(B+2*(57.7-0.118*TC)*1e-6)/(8.314*TC))
+
+
 	DD=-((-Kb*bor)/((h+Kb)*(h+Kb)))-(-Kw/((h)*(h)))+1;
 	A= (2*K2*(2*CO3+HCO3)+h*(h+2*K2)*DD)/((h+2*K2)*(h+2*K2));
 	B=( ( (2*CO3+HCO3) * h)/((h+2*K2)*K1) + (h/K1)* A );
 	C= (-K2*(2*CO3+HCO3)+K2*(2*K2+h)*DD)/((h+2*K2)*(h+2*K2));
 	PhiD=-1/(h*log(10) * ( B+A+C ) );
 	BetaD=-h*log(10)*DIC/CO2*B*PhiD;
-			
-			
+
+
 	Q=(h+2*K2);
-	V=(Kb*bor)/((h+Kb)*(h+Kb)) + Kw/(h*h)+1;         
+	V=(Kb*bor)/((h+Kb)*(h+Kb)) + Kw/(h*h)+1;
 			
 				
 	DB=(( K2*(2*CO3+HCO3)+ Q*V *(h+K2)+(h/K1)*( (2*CO3+HCO3)*Q+2*K2*(2*CO3+HCO3)+h*Q*V))/Q)*(1/(Q-(h+K2+h*h/K1)))-((-Kb*bor)/((h+Kb)*(h+Kb)))-(-Kw/((h)*(h)))+1;
@@ -737,9 +751,9 @@ for (i in 1:n)
 		write.table(res,resultat,sep="	",append=TRUE,row.names=FALSE);
 		}
 	}
-	
+
 	if (ini=='f')
-	
+
 	{
 	Salinity=S;
 	Temperature=paste(T,"oC");
@@ -754,10 +768,10 @@ for (i in 1:n)
 	ALK=paste(ALK,"(mol/kg)");
 	OmegaAragonite=Oa;
 	OmegaCalcite=Oc;
-	
+
 	res<-data.frame(Salinity,Temperature,Pressure,pH,CO2,pCO2,fCO2,HCO3,CO3,DIC,ALK,OmegaAragonite,OmegaCalcite,PhiD,BetaD,PiD,PhiB,BetaB,PiB,PhiC,BetaC,PiC,PhiH,PiH);
-	
-	
+
+
 	if(i==1)
 	{
 	write.table(res,resu,sep="	",append=TRUE,row.names=FALSE);
@@ -766,19 +780,19 @@ for (i in 1:n)
 	{
 	write.table(res,resu,sep="	",append=TRUE,row.names=FALSE,col.names=FALSE);
 	}
-	
-	}
-	
+
 	}
 
-	
-	
+	}
+
+
+
 
 
 
 
 	# ------------ CO2 and HCO3 given ------------------
-	
+
 	CO2HCO3 <- function(CO2, HCO3, K1, K2, bor, Kb, Kw, Kh, Kspa, Kspc, S, TC, P)
 	{
 	#disp('flag = 2, CO2 and HCO3 given');
@@ -792,7 +806,6 @@ for (i in 1:n)
 	r = polyroot(p);
 	h = max(Re(r));
 	pCO2=s*1.e6/Kh;
-	h*1e12;
 	DIC = s*(1.+K1/h+K1*K2/h/h);
 	CO3 = DIC/(1+h/K2+h*h/K1/K2);
 	ALK = s*(K1/h+2*K1*K2/h/h)+Kb*bor/(Kb+h)+Kw/h-h;
@@ -803,9 +816,12 @@ for (i in 1:n)
 	Oc = ((0.01028*(S/35))*CO3)/Kspc;
 	
 		
-	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
-	fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
-	
+	# JME: corrected fugacity calculation
+	# B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
+	# fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
+	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))*1e-6;
+	fCO2= pCO2*exp(((P+1)*100000)*(B+2*(57.7-0.118*TC)*1e-6)/(8.314*TC))
+
 	
 	DD=-((-Kb*bor)/((h+Kb)*(h+Kb)))-(-Kw/((h)*(h)))+1;
 	A= (2*K2*(2*CO3+HCO3)+h*(h+2*K2)*DD)/((h+2*K2)*(h+2*K2));
@@ -928,7 +944,7 @@ for (i in 1:n)
 
 
 	# ------------ CO2 and CO3 given ------------------
-	
+
 	CO2CO3 <- function(CO2, CO3, K1, K2, bor, Kb, Kw, Kh, Kspa, Kspc, S, TC, P)
 	{
 	#disp('flag = 3, CO2 and CO3 given');
@@ -943,7 +959,6 @@ for (i in 1:n)
 	r = polyroot(p);
 	h = max(Re(r));
 	pCO2=s*1.e6/Kh;
-	h*1e12;
 	DIC = s*(1.+K1/h+K1*K2/h/h);
 	HCO3 = DIC/(1+h/K1+K2/h);
 	ALK = s*(K1/h+2.*K1*K2/h/h)+Kb*bor/(Kb+h)+Kw/h-h;
@@ -954,9 +969,12 @@ for (i in 1:n)
 	Oc = ((0.01028*(S/35))*CO3)/Kspc;
 	
 		
-	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
-	fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
-	
+	# JME: corrected fugacity calculation
+	# B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
+	# fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
+	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))*1e-6;
+	fCO2= pCO2*exp(((P+1)*100000)*(B+2*(57.7-0.118*TC)*1e-6)/(8.314*TC))
+
 	
 	DD=-((-Kb*bor)/((h+Kb)*(h+Kb)))-(-Kw/((h)*(h)))+1;
 	A= (2*K2*(2*CO3+HCO3)+h*(h+2*K2)*DD)/((h+2*K2)*(h+2*K2));
@@ -1094,7 +1112,6 @@ for (i in 1:n)
 	p = c(p0, p1, p2, p3, p4);
 	r = polyroot(p);
 	h = max(Re(r));
-	h*1e12;
 	pCO2=s*1.e6/Kh;
 	DIC = s*(1.+K1/h+K1*K2/h/h);
 	HCO3 = DIC/(1+h/K1+K2/h);
@@ -1106,9 +1123,11 @@ for (i in 1:n)
 	Oc = ((0.01028*(S/35))*CO3)/Kspc;
 	
 		
-	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
-	fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
-	
+	# JME: corrected fugacity calculation
+	# B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
+	# fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
+	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))*1e-6;
+	fCO2= pCO2*exp(((P+1)*100000)*(B+2*(57.7-0.118*TC)*1e-6)/(8.314*TC))
 	
 	DD=-((-Kb*bor)/((h+Kb)*(h+Kb)))-(-Kw/((h)*(h)))+1;
 	A= (2*K2*(2*CO3+HCO3)+h*(h+2*K2)*DD)/((h+2*K2)*(h+2*K2));
@@ -1232,7 +1251,7 @@ for (i in 1:n)
 	
 
 	# ------------ CO2 and DIC given ------------------
-	
+
 	CO2DIC <- function(CO2, DIC, K1, K2, bor, Kb, Kw, Kh, Kspa, Kspc, S, TC, P)
 	{
 	#disp('flag = 5, CO2 and DIC given');
@@ -1245,7 +1264,6 @@ for (i in 1:n)
 	r = polyroot(p);
 	h = max(Re(r));
 	PH=-log10(h);
-	h*1e12;
 	pCO2=s*1.e6/Kh;
 	HCO3 = DIC/(1+h/K1+K2/h);
 	CO3 = DIC/(1+h/K2+h*h/K1/K2);
@@ -1256,9 +1274,12 @@ for (i in 1:n)
 	Oc = ((0.01028*(S/35))*CO3)/Kspc;
 	
 		
-	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
-	fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
-	
+	# JME: corrected fugacity calculation
+	# B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
+	# fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
+	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))*1e-6;
+	fCO2= pCO2*exp(((P+1)*100000)*(B+2*(57.7-0.118*TC)*1e-6)/(8.314*TC))
+
 	
 	DD=-((-Kb*bor)/((h+Kb)*(h+Kb)))-(-Kw/((h)*(h)))+1;
 	A= (2*K2*(2*CO3+HCO3)+h*(h+2*K2)*DD)/((h+2*K2)*(h+2*K2));
@@ -1388,7 +1409,6 @@ for (i in 1:n)
 	HCO3 = HCO3;
 	DIC = HCO3 * (1+h/K1+K2/h);
 	s = DIC / (1.+K1/h+K1*K2/h/h);
-	h*1e12;
 	CO3 = DIC/(1+h/K2+h*h/K1/K2);
 	ALK = s*(K1/h+2.*K1*K2/h/h)+Kb*bor/(Kb+h)+Kw/h-h;
 	CO2=s;
@@ -1398,9 +1418,12 @@ for (i in 1:n)
 	Oc = ((0.01028*(S/35))*CO3)/Kspc;
 	
 		
-	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
-	fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
-	
+	# JME: corrected fugacity calculation
+	# B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
+	# fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
+	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))*1e-6;
+	fCO2= pCO2*exp(((P+1)*100000)*(B+2*(57.7-0.118*TC)*1e-6)/(8.314*TC))
+
 	
 	DD=-((-Kb*bor)/((h+Kb)*(h+Kb)))-(-Kw/((h)*(h)))+1;
 	A= (2*K2*(2*CO3+HCO3)+h*(h+2*K2)*DD)/((h+2*K2)*(h+2*K2));
@@ -1532,7 +1555,6 @@ for (i in 1:n)
 	CO3 = CO3;
 	DIC = CO3 * (1+h/K2+h*h/K1/K2);
 	s = DIC / (1.+K1/h+K1*K2/h/h);
-	h*1e12;
 	HCO3 = DIC/(1+h/K1+K2/h);
 	ALK = s*(K1/h+2.*K1*K2/h/h)+Kb*bor/(Kb+h)+Kw/h-h;
 	CO2=s;
@@ -1542,9 +1564,12 @@ for (i in 1:n)
 	Oc = ((0.01028*(S/35))*CO3)/Kspc;
 	
 		
-	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
-	fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
-	
+	# JME: corrected fugacity calculation
+	# B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
+	# fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
+	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))*1e-6;
+	fCO2= pCO2*exp(((P+1)*100000)*(B+2*(57.7-0.118*TC)*1e-6)/(8.314*TC))
+
 	
 	DD=-((-Kb*bor)/((h+Kb)*(h+Kb)))-(-Kw/((h)*(h)))+1;
 	A= (2*K2*(2*CO3+HCO3)+h*(h+2*K2)*DD)/((h+2*K2)*(h+2*K2));
@@ -1675,7 +1700,6 @@ for (i in 1:n)
 	h =10^(-PH);
 	ALK = ALK;
 	s = (ALK-Kw/h+h-Kb*bor/(Kb+h)) / (K1/h+2.*K1*K2/h/h);
-	h*1e12;
 	DIC = s*(1.+K1/h+K1*K2/h/h);
 	HCO3 = DIC/(1+h/K1+K2/h);
 	CO3 = DIC/(1+h/K2+h*h/K1/K2);
@@ -1687,10 +1711,13 @@ for (i in 1:n)
 	Oc = ((0.01028*(S/35))*CO3)/Kspc;
 	
 		
-	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
-	fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
-	
-	
+	# JME: corrected fugacity calculation
+	# B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
+	# fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
+	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))*1e-6;
+	fCO2= pCO2*exp(((P+1)*100000)*(B+2*(57.7-0.118*TC)*1e-6)/(8.314*TC))
+
+
 	DD=-((-Kb*bor)/((h+Kb)*(h+Kb)))-(-Kw/((h)*(h)))+1;
 	A= (2*K2*(2*CO3+HCO3)+h*(h+2*K2)*DD)/((h+2*K2)*(h+2*K2));
 	B=( ( (2*CO3+HCO3) * h)/((h+2*K2)*K1) + (h/K1)* A );
@@ -1779,23 +1806,37 @@ for (i in 1:n)
 	if (ini=='f')
 	
 	{
+    # Salinity=S;
+    # Temperature=paste(T,"oC");
+    # Pressure=paste(P,"bar");
+    # pH=PH;
+    # CO2=paste(CO2,"(mol/kg)");
+    # pCO2=paste(pCO2,"(uatm)");
+    # fCO2=paste(fCO2,"(uatm)");
+    # HCO3=paste(HCO3,"(mol/kg)");
+    # CO3=paste(CO3,"(mol/kg)");
+    # DIC=paste(DIC,"(mol/kg)");
+    # ALK=paste(ALK,"(mol/kg)");
+    # OmegaAragonite=Oa;
+    # OmegaCalcite=Oc;
+
 	Salinity=S;
-	Temperature=paste(T,"oC");
-	Pressure=paste(P,"bar");
+	Temperature=T
+	Pressure=P
 	pH=PH;
-	CO2=paste(CO2,"(mol/kg)");
-	pCO2=paste(pCO2,"(uatm)");
-	fCO2=paste(fCO2,"(uatm)");
-	HCO3=paste(HCO3,"(mol/kg)");
-	CO3=paste(CO3,"(mol/kg)");
-	DIC=paste(DIC,"(mol/kg)");
-	ALK=paste(ALK,"(mol/kg)");
+	CO2=CO2
+	pCO2=pCO2
+	fCO2=fCO2
+	HCO3=HCO3
+	CO3=CO3
+	DIC=DIC
+	ALK=ALK
 	OmegaAragonite=Oa;
 	OmegaCalcite=Oc;
-	
+
 	res<-data.frame(Salinity,Temperature,Pressure,pH,CO2,pCO2,fCO2,HCO3,CO3,DIC,ALK,OmegaAragonite,OmegaCalcite,PhiD,BetaD,PiD,PhiB,BetaB,PiB,PhiC,BetaC,PiC,PhiH,PiH);
-	
-	
+
+
 	if(i==1)
 	{
 	write.table(res,resu,sep="	",append=TRUE,row.names=FALSE);
@@ -1822,7 +1863,6 @@ for (i in 1:n)
 	h =10^(-PH);
 	DIC = DIC;
 	s = DIC / (1.+K1/h+K1*K2/h/h);
-	h*1e12;
 	HCO3 = DIC/(1+h/K1+K2/h);
 	CO3 = DIC/(1+h/K2+h*h/K1/K2);
 	ALK = s*(K1/h+2.*K1*K2/h/h)+Kb*bor/(Kb+h)+Kw/h-h;
@@ -1833,9 +1873,12 @@ for (i in 1:n)
 	Oc = ((0.01028*(S/35))*CO3)/Kspc;
 	
 		
-	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
-	fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
-	
+	# JME: corrected fugacity calculation
+	# B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
+	# fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
+	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))*1e-6;
+	fCO2= pCO2*exp(((P+1)*100000)*(B+2*(57.7-0.118*TC)*1e-6)/(8.314*TC))
+
 	
 	DD=-((-Kb*bor)/((h+Kb)*(h+Kb)))-(-Kw/((h)*(h)))+1;
 	A= (2*K2*(2*CO3+HCO3)+h*(h+2*K2)*DD)/((h+2*K2)*(h+2*K2));
@@ -1962,7 +2005,7 @@ for (i in 1:n)
 
 	HCO3CO3 <- function(HCO3, CO3, K1, K2, bor, Kb, Kw, Kh, Kspa, Kspc, S, TC, P)
 	{
-		
+	
 	#disp('flag = 10, HCO3 and CO3 given');
 	HCO3 = HCO3;  
 	CO3 = CO3;
@@ -1974,7 +2017,6 @@ for (i in 1:n)
 	r = polyroot(p);
 	h = max(Re(r));
 	PH=-log10(h);
-	h*1e12;
 	DIC = HCO3 * (1+h/K1+K2/h);
 	s = DIC / (1.+K1/h+K1*K2/h/h);
 	ALK = s*(K1/h+2.*K1*K2/h/h)+Kb*bor/(Kb+h)+Kw/h-h;
@@ -1986,9 +2028,12 @@ for (i in 1:n)
 	Oc = ((0.01028*(S/35))*CO3)/Kspc;
 	
 		
-	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
-	fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
-	
+	# JME: corrected fugacity calculation
+	# B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
+	# fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
+	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))*1e-6;
+	fCO2= pCO2*exp(((P+1)*100000)*(B+2*(57.7-0.118*TC)*1e-6)/(8.314*TC))
+
 	
 	DD=-((-Kb*bor)/((h+Kb)*(h+Kb)))-(-Kw/((h)*(h)))+1;
 	A= (2*K2*(2*CO3+HCO3)+h*(h+2*K2)*DD)/((h+2*K2)*(h+2*K2));
@@ -2131,7 +2176,6 @@ for (i in 1:n)
 	r = polyroot(p);
 	h = max(Re(r));
 	PH=-log10(h);
-	h*1e12;               
 	DIC = HCO3 * (1+h/K1+K2/h);
 	s = DIC / (1.+K1/h+K1*K2/h/h);
 	CO3 = DIC/(1+h/K2+h*h/K1/K2);
@@ -2143,9 +2187,12 @@ for (i in 1:n)
 	Oc = ((0.01028*(S/35))*CO3)/Kspc;
 	
 		
-	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
-	fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
-	
+	# JME: corrected fugacity calculation
+	# B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
+	# fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
+	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))*1e-6;
+	fCO2= pCO2*exp(((P+1)*100000)*(B+2*(57.7-0.118*TC)*1e-6)/(8.314*TC))
+
 	
 	DD=-((-Kb*bor)/((h+Kb)*(h+Kb)))-(-Kw/((h)*(h)))+1;
 	A= (2*K2*(2*CO3+HCO3)+h*(h+2*K2)*DD)/((h+2*K2)*(h+2*K2));
@@ -2282,7 +2329,6 @@ for (i in 1:n)
 	r = polyroot(p);
 	h = min(Re(r));       # min instead of max !!!!!
 	PH=-log10(h);
-	h*1e12;
 	s = DIC / (1.+K1/h+K1*K2/h/h);
 	DIC = s*(1.+K1/h+K1*K2/h/h);
 	CO3 = DIC/(1+h/K2+h*h/K1/K2);
@@ -2294,9 +2340,12 @@ for (i in 1:n)
 	Oc = ((0.01028*(S/35))*CO3)/Kspc;
 	
 		
-	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
-	fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
-	
+	# JME: corrected fugacity calculation
+	# B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
+	# fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
+	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))*1e-6;
+	fCO2= pCO2*exp(((P+1)*100000)*(B+2*(57.7-0.118*TC)*1e-6)/(8.314*TC))
+
 	
 	DD=-((-Kb*bor)/((h+Kb)*(h+Kb)))-(-Kw/((h)*(h)))+1;
 	A= (2*K2*(2*CO3+HCO3)+h*(h+2*K2)*DD)/((h+2*K2)*(h+2*K2));
@@ -2439,7 +2488,6 @@ for (i in 1:n)
 	r = polyroot(p);
 	h = max(Re(r));
 	PH=-log10(h);
-	h*1e12;
 	DIC = CO3 * (1+h/K2+h^2/K1/K2);
 	s = DIC / (1.+K1/h+K1*K2/h/h);
 	HCO3 = DIC/(1+h/K1+K2/h);
@@ -2450,9 +2498,12 @@ for (i in 1:n)
 	Oc = ((0.01028*(S/35))*CO3)/Kspc;
 	
 		
-	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
-	fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
-	
+	# JME: corrected fugacity calculation
+	# B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
+	# fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
+	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))*1e-6;
+	fCO2= pCO2*exp(((P+1)*100000)*(B+2*(57.7-0.118*TC)*1e-6)/(8.314*TC))
+
 	
 	DD=-((-Kb*bor)/((h+Kb)*(h+Kb)))-(-Kw/((h)*(h)))+1;
 	A= (2*K2*(2*CO3+HCO3)+h*(h+2*K2)*DD)/((h+2*K2)*(h+2*K2));
@@ -2589,21 +2640,23 @@ for (i in 1:n)
 	r = polyroot(p);
 	h = max(Re(r));
 	PH=-log10(h);
-	h*1e12;
 	s = DIC / (1.+K1/h+K1*K2/h/h);
 	HCO3 = DIC/(1+h/K1+K2/h);
 	ALK = s*(K1/h+2.*K1*K2/h/h)+Kb*bor/(Kb+h)+Kw/h-h;
 	CO2=s;
 	pCO2=s*1.e6/Kh;
-	
+
 	
 	Oa = ((0.01028*(S/35))*CO3)/Kspa;
 	Oc = ((0.01028*(S/35))*CO3)/Kspc;
 	
 		
-	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
-	fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
-	
+	# JME: corrected fugacity calculation
+	# B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
+	# fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
+	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))*1e-6;
+	fCO2= pCO2*exp(((P+1)*100000)*(B+2*(57.7-0.118*TC)*1e-6)/(8.314*TC))
+
 	
 	DD=-((-Kb*bor)/((h+Kb)*(h+Kb)))-(-Kw/((h)*(h)))+1;
 	A= (2*K2*(2*CO3+HCO3)+h*(h+2*K2)*DD)/((h+2*K2)*(h+2*K2));
@@ -2718,16 +2771,16 @@ for (i in 1:n)
 	{
 	write.table(res,resu,sep="	",append=TRUE,row.names=FALSE,col.names=FALSE);
 	}
-	
+
 	}
-	
+
 	}
 
 
 
 
 	# ------------ ALK and DIC given ------------------
-	
+
 	ALKDIC <- function(ALK, DIC, K1, K2, bor, Kb, Kw, Kh, Kspa, Kspc, S, TC, P)
 	{
 	#disp('flag = 15, ALK and DIC given');
@@ -2745,63 +2798,65 @@ for (i in 1:n)
 	r = polyroot(p);
 	h = max(Re(r));
 	PH=-log10(h);
-	h*1e12;
 	s = DIC / (1.+K1/h+K1*K2/h/h);
 	HCO3 = DIC/(1+h/K1+K2/h);
 	CO3 = DIC/(1+h/K2+h*h/K1/K2);
 	CO2=s;
 	pCO2=s*1.e6/Kh;
-	
+
 	Oa = ((0.01028*(S/35))*CO3)/Kspa;
 	Oc = ((0.01028*(S/35))*CO3)/Kspc;
-	
-		
-	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
-	fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
-	
-	
+
+
+	# JME: corrected fugacity calculation
+	# B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))^-6;
+	# fCO2= pCO2*exp(((P+1)*100000)*(B+2*((57.7-0.118*TC)^-6))/(8.314*TC))
+	B=(-1636.75+12.0408*TC-0.0327957*(TC*TC)+0.0000316528*(TC*TC*TC))*1e-6;
+	fCO2= pCO2*exp(((P+1)*100000)*(B+2*(57.7-0.118*TC)*1e-6)/(8.314*TC))
+
+
 	DD=-((-Kb*bor)/((h+Kb)*(h+Kb)))-(-Kw/((h)*(h)))+1;
 	A= (2*K2*(2*CO3+HCO3)+h*(h+2*K2)*DD)/((h+2*K2)*(h+2*K2));
 	B=( ( (2*CO3+HCO3) * h)/((h+2*K2)*K1) + (h/K1)* A );
 	C= (-K2*(2*CO3+HCO3)+K2*(2*K2+h)*DD)/((h+2*K2)*(h+2*K2));
 	PhiD=-1/(h*log(10) * ( B+A+C ) );
 	BetaD=-h*log(10)*DIC/CO2*B*PhiD;
-			
-				
+
+
 	Q=(h+2*K2);
-	V=(Kb*bor)/((h+Kb)*(h+Kb)) + Kw/(h*h)+1;         
-			
-					
+	V=(Kb*bor)/((h+Kb)*(h+Kb)) + Kw/(h*h)+1;
+
+
 	DB=(( K2*(2*CO3+HCO3)+ Q*V *(h+K2)+(h/K1)*( (2*CO3+HCO3)*Q+2*K2*(2*CO3+HCO3)+h*Q*V))/Q)*(1/(Q-(h+K2+h*h/K1)))-((-Kb*bor)/((h+Kb)*(h+Kb)))-(-Kw/((h)*(h)))+1;
 	A= (2*K2*(2*CO3+HCO3)+h*(h+2*K2)*DB)/((h+2*K2)*(h+2*K2));
 	B=( ( (2*CO3+HCO3) * h)/((h+2*K2)*K1) + (h/K1)* A );
 	C= (-K2*(2*CO3+HCO3)+K2*(2*K2+h)*DB)/((h+2*K2)*(h+2*K2));
 	PhiB=-1/(h*log(10) * ( B+A+C ) );
 	BetaB=-h*log(10)*DIC/CO2*B*PhiB;
-				
-				
+
+
 	DC=2*(( K2*(2*CO3+HCO3)+ Q*V *(h+K2)+(h/K1)*( (2*CO3+HCO3)*Q+2*K2*(2*CO3+HCO3)+h*Q*V))/Q)*(1/(Q-2*(h+K2+h*h/K1)))-((-Kb*bor)/((h+Kb)*(h+Kb)))-(-Kw/((h)*(h)))+1;
 	A= (2*K2*(2*CO3+HCO3)+h*(h+2*K2)*DC)/((h+2*K2)*(h+2*K2));
 	B=( ( (2*CO3+HCO3) * h)/((h+2*K2)*K1) + (h/K1)* A );
 	C= (-K2*(2*CO3+HCO3)+K2*(2*K2+h)*DC)/((h+2*K2)*(h+2*K2));
 	PhiC=-1/(h*log(10) * ( B+A+C ) );
 	BetaC=-h*log(10)*DIC/CO2*B*PhiC;
-				
-			
+
+
 	D1=(K1*(K1*K2-h*h)*DIC)   /  ((h*h+h*K1+K1*K2)*(h*h+h*K1+K1*K2));
 	D2=(-K1*K2*(2*h+K1)*DIC)  /  ((h*h+h*K1+K1*K2)*(h*h+h*K1+K1*K2));
 	D=D1+2*D2;
-	PhiH=1/ (h*log(10)* (D +(-Kb*bor/((h+Kb)*(h+Kb)))  + (-Kw/(h*h))-1))  ;   
-			
-		
+	PhiH=1/ (h*log(10)* (D +(-Kb*bor/((h+Kb)*(h+Kb)))  + (-Kw/(h*h))-1))  ;
+
+
 	Pi=(h*K1*(h+2*K2)*DIC)  /  ((h*h+h*K1+K1*K2)*(h*h+h*K1+K1*K2));
 	PiH=((-h/Kh)*log(10)*Pi)*PhiH;
 	PiB=CO2/(Kh*DIC)*BetaB;
 	PiD=CO2/(Kh*DIC)*BetaD;
 	PiC=CO2/(Kh*DIC)*BetaC;
-		
-		
-		
+
+
+
 	if (ini=='s')
 	{
 	cat("Salinity:\t\t",S,"\n");
@@ -2844,27 +2899,41 @@ for (i in 1:n)
 		}
 	}
 
-	
+
 	if (ini=='f')
-	
+
 	{
+    # Salinity=S;
+    # Temperature=paste(T,"oC");
+    # Pressure=paste(P,"bar");
+    # pH=PH;
+    # CO2=paste(CO2,"(mol/kg)");
+    # pCO2=paste(pCO2,"(uatm)");
+    # fCO2=paste(fCO2,"(uatm)");
+    # HCO3=paste(HCO3,"(mol/kg)");
+    # CO3=paste(CO3,"(mol/kg)");
+    # DIC=paste(DIC,"(mol/kg)");
+    # ALK=paste(ALK,"(mol/kg)");
+    # OmegaAragonite=Oa;
+    # OmegaCalcite=Oc;
+
 	Salinity=S;
-	Temperature=paste(T,"oC");
-	Pressure=paste(P,"bar");
+	Temperature=T
+	Pressure=P
 	pH=PH;
-	CO2=paste(CO2,"(mol/kg)");
-	pCO2=paste(pCO2,"(uatm)");
-	fCO2=paste(fCO2,"(uatm)");
-	HCO3=paste(HCO3,"(mol/kg)");
-	CO3=paste(CO3,"(mol/kg)");
-	DIC=paste(DIC,"(mol/kg)");
-	ALK=paste(ALK,"(mol/kg)");
+	CO2=CO2
+	pCO2=pCO2
+	fCO2=fCO2
+	HCO3=HCO3
+	CO3=CO3
+	DIC=DIC
+	ALK=ALK
 	OmegaAragonite=Oa;
 	OmegaCalcite=Oc;
-	
+
 	res<-data.frame(Salinity,Temperature,Pressure,pH,CO2,pCO2,fCO2,HCO3,CO3,DIC,ALK,OmegaAragonite,OmegaCalcite,PhiD,BetaD,PiD,PhiB,BetaB,PiB,PhiC,BetaC,PiC,PhiH,PiH);
-	
-	
+
+
 	if(i==1)
 	{
 	write.table(res,resu,sep="	",append=TRUE,row.names=FALSE);
@@ -2873,9 +2942,9 @@ for (i in 1:n)
 	{
 	write.table(res,resu,sep="	",append=TRUE,row.names=FALSE,col.names=FALSE);
 	}
-	
+
 	}
-	
+
 	}
 
 
@@ -2884,12 +2953,12 @@ for (i in 1:n)
 	{
 	PHCO2(PH, CO2, K1, K2, bor, Kb, Kw, Kh, Kspa, Kspc, S, TC, P);
 	}
-	
+
 	if (flag==2)
 	{
 	CO2HCO3(CO2, HCO3, K1, K2, bor, Kb, Kw, Kh, Kspa, Kspc, S, TC, P);
 	}
-	
+
 	if (flag==3)
 	{
 	CO2CO3(CO2, CO3, K1, K2, bor, Kb, Kw, Kh, Kspa, Kspc, S, TC, P);
@@ -2914,7 +2983,7 @@ for (i in 1:n)
 	{
 	PHCO3(PH, CO3, K1, K2, bor, Kb, Kw, Kh, Kspa, Kspc, S, TC, P);
 	}
-	
+
 	if (flag==8)
 	{
 	PHALK(PH, ALK, K1, K2, bor, Kb, Kw, Kh, Kspa, Kspc, S, TC, P);
